package com.xhly.manageapp


import android.Manifest
import android.app.csdk.CSDKManager
import android.content.pm.PackageManager
import android.os.Build
import androidx.core.content.ContextCompat
import androidx.multidex.MultiDexApplication
import com.hjq.toast.Toaster
import com.xhly.corelib.utils.ModelNameUtils
import com.xhly.manageapp.service.websocket.AppSocket
import com.xhly.manageapp.utils.ZJAPPUtils
import java.io.File

class ManageApplication : MultiDexApplication() {
    companion object {
        @JvmStatic
        var instance: ManageApplication?=null
            private set
        private var csdkManager: CSDKManager? = null

        private var apppSocket: AppSocket? = null

        /**
         * 加入可安装应用白名单
         */
        fun addInstallPackageWhiteList(pkgList: ArrayList<String>) {
            if (ModelNameUtils.IS_LianxX505f()) {
                pkgList.add("com.xhly.manageapp")
                csdkManager?.addInstallPackageWhiteList(pkgList)
            }
        }

        /**
         * 移除可安装应用白名单
         */
        fun removeInstallPackageWhiteList(pkgList: ArrayList<String>) {
            if (ModelNameUtils.IS_LianxX505f() && pkgList.size > 0) {
                pkgList.remove("com.xhly.manageapp")
                csdkManager?.removeInstallPackageWhiteList(pkgList)
            }
        }


        /**
         * 获取应用白名单
         */
        fun getInstallPackageWhiteList(): ArrayList<String> {
            try {
                if (ModelNameUtils.IS_LianxX505f()) {
                    return csdkManager?.installPackageWhiteList as ArrayList<String>
                }
            } catch (e: Exception) {

            }
            return arrayListOf(
                "com.xhly.manageapp",
                "com.xhkjedu.xh_control_appstore"
            )
        }

        /**
         * 安装应用
         */

        fun installPackage(string: String) {
            val installPackageWhiteList = getInstallPackageWhiteList()
            installPackageWhiteList.add(string)
            addInstallPackageWhiteList(installPackageWhiteList)
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.installPackage(string)
            } else {
                instance?.let {
                    ZJAPPUtils.installApk(it, File(string))
                }
            }
        }

        /**
         * 卸载应用
         */

        fun uninstallPackage(pkg: String) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.uninstallPackage(pkg, false)
            }
        }

        /**
         * 禁止安装app,true：禁止安装应用 false：取消禁止安装应用,禁止时静默安装只能安装白名单内的应用，不禁止时静默安装可以安装白名单外的应用
         */
        fun disableInstallation(isInstall: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.disableInstallation(isInstall)
            }
        }

        /**
         * 冻结应用true：显示应用可以使用; false：隐藏应用不可用
         */
        fun setPackageEnabled(pkg: String, enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                //TODO 暂不处理系统应用
                if (!pkg.startsWith("com.android.")){
                    csdkManager?.setPackageEnabled(pkg, enableFlag)
                }
            }
        }

        /**
         * 设置显示黑名单,控制桌面是否显示图标
         */
        fun setDisplayBlacklist(pkgList: ArrayList<String>) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.displayBlacklist_v3 = pkgList
            }
        }

        /**
         * 杀进程
         */
        fun killApplicationProcess(pkg: String) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.killApplicationProcess(pkg)
            }
        }

        /**
         * 禁用摄像头 true：禁用相机
         * false：启用相机
         */
        fun disableCamera(enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.disableCamera(enableFlag)
            }
        }

        /**
         * 打开关闭蓝牙true：打开蓝牙
         * false：关闭蓝牙
         */
        fun enableBluetooth(enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.enableBluetooth_v3(enableFlag)
            }
        }

        /**
         * 打开关闭usb调试,true：打开
         */
        fun disallowUsbDebugging(enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.disallowUsbDebugging_v3(enableFlag)
            }
        }

        /**
         * 禁止用户操作 wifi true：不可操作false：可以操作
         */
        fun disallowWifi(enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.disallowWifi_v3(enableFlag)
            }
        }

        /**
         * 打开关闭 wifi true：打开 wifi false：关闭 wifi
         */
        fun enableWifi(enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.enableWifi_v3(enableFlag)
            }
        }

        /**
         * 禁止用户操作移动数据 true：不可操作 false：可以操作
         */
        fun disallowData(enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.disallowData_v3(enableFlag)
            }
        }

        /**
         * 打开关闭移动数据 true：打开 false：关闭
         */
        fun enableData(enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.enableData_v3(enableFlag)
            }
        }

        /**
         * 禁止操作位置 true：不可操作 false：可以操作
         */
        fun disallowLocation(enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.disallowLocation_v3(enableFlag)
            }
        }

        /**
         * 打开关闭位置 true：打开 false：关闭
         */
        fun enableLocation(enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.enableLocation_v3(enableFlag)
            }
        }

        /**
         * 禁止操作 wifi 高级设置 true：不可操作 false：可以操作
         */
        fun disallowWifiAdvanceSettings(enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.disallowWifiadvancesettings_v3(enableFlag)
            }
        }

        /**
         *禁用/启用SD卡 true：允许连接外部存储设备
         */
        fun enableMassStorage(enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.enableMassStorage(enableFlag)
            }
        }

        /**
         *禁用/启用OTG true：允许连接外部OTG
         */
        fun setCustomOTG(enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.customOTG= enableFlag
            }
        }

        /**
         * 设置运行时权限
         */
        fun setRuntimePermissions(enableFlag: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.setRuntimePermissions(enableFlag)
            }
        }

        /**
         * "设备Mac地址", "设备SN号", "获取设备型号信息", "获取设备IMEI信息" 1,2,3,4
         */
        fun getDeviceInfo(type: Int = 2): String? {
            if (ModelNameUtils.IS_LianxX505f()) {
                return csdkManager?.getDeviceInfo(type)
            }
            try {
                if (instance!=null&&ContextCompat.checkSelfPermission(instance!!.applicationContext,Manifest.permission.READ_PHONE_STATE)== PackageManager.PERMISSION_GRANTED){
                    val serial = if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                        Build.getSerial()
                    } else {
                        Build.SERIAL
                    }
                    return if (serial.isNullOrBlank()) {
                        ""
                    } else {
                        serial
                    }
                }else{
                    return ""
                }
            }catch (e:Exception){
                return ""
            }
        }

        /**
         * 恢复出场设置
         */
        fun launchFactoryReset() {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.launchFactoryReset()
            }
        }

        /**
         *重启设备
         */

        fun rebootDevice() {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.rebootDevice()
            }
        }

        /**
         * 增加wifi白名单
         */
        fun addWifiWhiteList(list: List<String>) {
            if (ModelNameUtils.IS_LianxX505f()) {
                csdkManager?.addWifiWhiteList(list)
            }
        }

        /**
         * 启用wifi白名单
         */
        fun enableWifiWhiteList(enable: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
               //csdkManager?.whitelist
            }
        }

        /**
         * 启用无障碍服务
         */
        fun enableAccessibility() {
            if (ModelNameUtils.IS_LianxX505f()) {
                //csdkManager?.enableAccessibility("com.xhly.manageapp","com.xhly.manageapp.service.TestService",true)
            }
        }

        /**
         * 禁用/启用截屏 true：允许截屏
         */
        fun enableCaptureScreen(enable: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                //csdkManager?.enableCaptureScreen_v3(enable)
            }
        }

        /**
         * 禁止/允许 设置自动旋转屏幕 true：禁止设置自动旋转屏幕
         */
        fun disallowSetAutoRotation(enable: Boolean) {
            if (ModelNameUtils.IS_LianxX505f()) {
                //csdkManager?.disallowSetAutoRotation(enable)
            }
        }
    }

    override fun onCreate() {
        super.onCreate()
        instance= this
        Toaster.init(this)
        apppSocket = AppSocket()
        apppSocket?.startSocket(this)
        if (ModelNameUtils.IS_LianxX505f()) {
            //是505f则执行
            csdkManager = CSDKManager(this)
            addInstallPackageWhiteList(
                arrayListOf(
                    "com.xhly.manageapp",
                    "com.xhkjedu.xh_control_appstore"
                )
            )
            // disableInstallation(false)
            setRuntimePermissions(true)
            enableAccessibility()
        }
    }

    override fun onTerminate() {
        super.onTerminate()
        apppSocket?.onDestroy()
    }
}