package com.xhly.manageapp.ui.login.activity

import BaseActivity
import android.Manifest
import android.annotation.SuppressLint
import android.content.pm.PackageManager
import android.graphics.Color
import android.os.Build
import android.view.View
import android.widget.EditText
import android.widget.TextView
import androidx.activity.addCallback
import com.kongzue.dialogx.dialogs.CustomDialog
import com.kongzue.dialogx.interfaces.OnBindView
import com.tbruyelle.rxpermissions2.RxPermissions
import com.xhly.corelib.Const
import com.xhly.corelib.utils.GsonUtils
import com.xhly.corelib.utils.SystemUtil
import com.xhly.manageapp.ManageApplication
import com.xhly.manageapp.R
import com.xhly.manageapp.bean.LoginBean
import com.xhly.manageapp.bean.user.UserBean
import com.xhly.manageapp.contentprovider.ZSpProvider
import com.xhly.manageapp.databinding.ActivityLoginBinding
import com.xhly.manageapp.ui.login.viewmodel.LoginViewModel
import com.xhly.manageapp.ui.main.activity.MainActivity

class LoginActivity : BaseActivity<LoginViewModel, ActivityLoginBinding>() {
    private var regioncode = ""
    override fun getBinding() = ActivityLoginBinding.inflate(layoutInflater)

    override fun initData() {
       viewModel.loginData.observe(this){
           if (it.xhlyLoginSucess){
               loginSucess(it)
           }else{
               it.xhlyLoginMessage?.let {
                   Toast(it)
               }
           }
       }
    }

    @SuppressLint("CheckResult")
    override fun initView() {
        setSoftInput(mBinding.root)
        mBinding.loginBtn.setOnClickListener {
            val rxPermissions = RxPermissions(this)
            val request = rxPermissions.request(Manifest.permission.READ_PHONE_STATE)
            request.subscribe({
                login()
            },{
                login()
            })
        }
        mBinding.codeLoginIv.setOnClickListener {
            showEditDialog()
        }
        onBackPressedDispatcher.addCallback {
            //屏蔽返回
        }
    }

    private fun login() {
        val account = mBinding.accountEt.text.toString()
        val code = mBinding.codeEt.text.toString()
        if (account.isNullOrBlank()) {
            Toast(getString(R.string.accountnoempty))
            return
        }
        if (code.isNullOrBlank()) {
            Toast(getString(R.string.codenoempty))
            return
        }
        val loginBean=LoginBean()
        loginBean.loginname=account
        loginBean.loginpwd=code
        loginBean.device= Build.BRAND
        loginBean.deviceModel=Build.MODEL
        loginBean.regionCode=regioncode
        loginBean.clientVersion=SystemUtil.getAppVersionName(this,packageName)
        ManageApplication.getDeviceInfo()?.let {
            loginBean.sn=it
        }
        viewModel.login(loginBean)
    }

    private fun loginSucess(userBean: UserBean){
        spUtils.saveJson(Const.USERINFO,userBean)
        val parseClassToJson = GsonUtils.parseClassToJson(userBean)
        ZSpProvider.save(this,Const.USERINFO,parseClassToJson)
        startIntentActivity(MainActivity().javaClass)
        finish()
    }


    private fun showEditDialog() {
        CustomDialog
            .build()
            .setCustomView(object : OnBindView<CustomDialog>(R.layout.layout_edit_dialog) {
                override fun onBind(dialog: CustomDialog, v: View) {
                    val enterTv = v.findViewById<TextView>(R.id.dialog_enter_tv)
                    val cancelTv = v.findViewById<TextView>(R.id.dialog_cancel_tv)
                    val editText = v.findViewById<EditText>(R.id.dialog_et)
                    enterTv.setOnClickListener {
                        dialog.dismiss()
                        val text = editText.text
                        val list= arrayListOf("com.xhly.manageapp")
                        spUtils.saveJson(Const.WHITELISTAPP,list)
                        regioncode = if (text != null && text.isNotEmpty()) {
                            text.toString()
                        } else {
                            ""
                        }
                    }
                    cancelTv.setOnClickListener {
                        dialog.dismiss()
                    }
                }
            }).setCancelable(false).setMaskColor(Color.parseColor("#66000000"))
            .setAlign(CustomDialog.ALIGN.CENTER).show()
    }
}